@@ -304,7 +304,7 @@ GtkEntryCompletion *completion;
 	menubutton = gtk_menu_button_new ();
 	//data->MB_template = menubutton;
 	image = gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_BUTTON);
-	gtk_container_add(GTK_CONTAINER(menubutton), image);
+	gtk_button_set_image(GTK_BUTTON(menubutton), image);
 	gtk_menu_button_set_direction (GTK_MENU_BUTTON(menubutton), GTK_ARROW_LEFT );
 	//gtk_widget_set_halign (menubutton, GTK_ALIGN_END);
 	gtk_box_pack_start(GTK_BOX(mainbox), menubutton, FALSE, FALSE, 0);
@@ -339,7 +339,7 @@ GtkEntryCompletion *completion;
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	//gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scrollwin), HB_MINHEIGHT_LIST);
 	treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(store));
-	gtk_container_add(GTK_CONTAINER(scrollwin), GTK_WIDGET(treeview));
+	gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scrollwin), treeview);
 	gtk_widget_show_all(box);
 
 	//gtk_widget_set_can_focus(GTK_WIDGET(treeview), FALSE);
@@ -1242,7 +1242,7 @@ guint32 key;
 		grid = gtk_grid_new();
 		gtk_grid_set_row_spacing (GTK_GRID (grid), SPACING_SMALL);
 		gtk_grid_set_column_spacing (GTK_GRID (grid), SPACING_MEDIUM);
-		gtk_container_set_border_width (GTK_CONTAINER(grid), SPACING_LARGE);
+		hb_widget_set_margin(GTK_WIDGET(grid), SPACING_LARGE);
 		gtk_box_pack_start (GTK_BOX (content_area), grid, TRUE, TRUE, 0);
 
 		// group :: General
@@ -1269,7 +1269,7 @@ guint32 key;
 		gtk_widget_set_size_request (scrollwin, -1, 24);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
-		gtk_container_add (GTK_CONTAINER (scrollwin), widget);
+		gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scrollwin), widget);
 		gtk_widget_set_hexpand (scrollwin, TRUE);
 		gtk_widget_set_vexpand (scrollwin, TRUE);
 		TB_notes = widget;
@@ -1376,10 +1376,11 @@ guint32 key;
 			if(notes != NULL)
 				item->notes = g_strdup(notes);
 			
+			//TODO: missing sort here
 	    }
 
 		// cleanup and destroy
-		gtk_widget_destroy (dialog);
+		gtk_window_destroy (GTK_WINDOW(dialog));
 	}
 
 }
@@ -1520,7 +1521,7 @@ GtkTreeIter iter;
 		}
 
 		// cleanup and destroy
-		gtk_widget_destroy (dialog);
+		gtk_window_destroy (GTK_WINDOW(dialog));
 	}
 
 }
@@ -1753,8 +1754,7 @@ GtkWidget *ui_pay_manage_dialog (void)
 {
 struct ui_pay_manage_dialog_data *data;
 GtkWidget *dialog, *content, *mainvbox, *vbox, *bbox, *treeview, *scrollwin, *table;
-GtkWidget *menu, *menuitem, *widget, *image, *addreveal, *tbar;
-GtkToolItem *toolitem;
+GtkWidget *menu, *menuitem, *widget, *image, *revealer, *tbar;
 gint w, h, dw, dh, row;
 
 	data = g_malloc0(sizeof(struct ui_pay_manage_dialog_data));
@@ -1793,7 +1793,7 @@ gint w, h, dw, dh, row;
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_LARGE);
+	hb_widget_set_margin(GTK_WIDGET(mainvbox), SPACING_LARGE);
 
     //our table
 	table = gtk_grid_new ();
@@ -1856,7 +1856,7 @@ gint w, h, dw, dh, row;
 	gtk_grid_attach (GTK_GRID (table), vbox, 0, row, 2, 1);
 
 	scrollwin = gtk_scrolled_window_new(NULL,NULL);
-	gtk_container_add(GTK_CONTAINER(vbox), scrollwin);
+	gtk_box_pack_start(GTK_BOX(vbox), scrollwin, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scrollwin), HB_MINHEIGHT_LIST);
@@ -1864,67 +1864,40 @@ gint w, h, dw, dh, row;
 	gtk_widget_set_vexpand (scrollwin, TRUE);
 	treeview = ui_pay_listview_new(FALSE, TRUE);
 	data->LV_pay = treeview;
-	gtk_container_add(GTK_CONTAINER(scrollwin), treeview);
+	gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scrollwin), treeview);
 
-	tbar = gtk_toolbar_new();
-	gtk_toolbar_set_icon_size (GTK_TOOLBAR(tbar), GTK_ICON_SIZE_MENU);
-	gtk_toolbar_set_style(GTK_TOOLBAR(tbar), GTK_TOOLBAR_ICONS);
+	tbar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
 	gtk_style_context_add_class (gtk_widget_get_style_context (tbar), GTK_STYLE_CLASS_INLINE_TOOLBAR);
 	gtk_box_pack_start (GTK_BOX (vbox), tbar, FALSE, FALSE, 0);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	toolitem = gtk_tool_item_new();
-	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
-
-		widget = make_image_toggle_button(ICONNAME_LIST_ADD, _("Add"));
-		data->BT_add = widget;
-		gtk_container_add (GTK_CONTAINER (bbox), widget);
-
-		widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
-		data->BT_delete = widget;
-		gtk_container_add (GTK_CONTAINER (bbox), widget);
-
-	toolitem = gtk_separator_tool_item_new ();
-	//gtk_tool_item_set_expand (toolitem, TRUE);
-	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+	gtk_box_pack_start (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+		data->BT_add = widget = make_image_toggle_button(ICONNAME_LIST_ADD, _("Add"));
+		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		data->BT_delete = widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete")); 
+		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	toolitem = gtk_tool_item_new();
-	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
-
-		widget = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
-		data->BT_edit = widget;
-		gtk_container_add (GTK_CONTAINER (bbox), widget);
-		
-		widget = make_image_button(ICONNAME_HB_LIST_MERGE, _("Move/Merge"));
-		data->BT_merge = widget;
-		gtk_container_add (GTK_CONTAINER (bbox), widget);
-
-	toolitem = gtk_separator_tool_item_new ();
-	//gtk_tool_item_set_expand (toolitem, TRUE);
-	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+	gtk_box_pack_start (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+		data->BT_edit = widget = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
+		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		data->BT_merge = widget = make_image_button(ICONNAME_HB_LIST_MERGE, _("Move/Merge"));
+		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	toolitem = gtk_tool_item_new();
-	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
-
-		widget = make_image_button(ICONNAME_HB_BUTTON_HIDE, _("Show/Hide"));
-		data->BT_hide = widget;
-		gtk_container_add (GTK_CONTAINER (bbox), widget);
+	gtk_box_pack_start (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+	
+		data->BT_hide = widget = make_image_button(ICONNAME_HB_BUTTON_HIDE, _("Show/Hide"));
+		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
 
 	row++;
-	addreveal = gtk_revealer_new ();
-	data->RE_addreveal = addreveal;
-	gtk_grid_attach (GTK_GRID (table), addreveal, 0, row, 2, 1);
+	revealer = gtk_revealer_new ();
+	data->RE_addreveal = revealer;
+	gtk_grid_attach (GTK_GRID (table), revealer, 0, row, 2, 1);
 	data->ST_name = gtk_entry_new ();
 	gtk_entry_set_placeholder_text(GTK_ENTRY(data->ST_name), _("new payee") );
 	gtk_widget_set_hexpand (data->ST_name, TRUE);
-	gtk_container_add(GTK_CONTAINER(addreveal), data->ST_name);
+	gtk_revealer_set_child (GTK_REVEALER(revealer), data->ST_name);
 	
 	
 	// connect dialog signals
@@ -1943,7 +1916,7 @@ gint w, h, dw, dh, row;
 	// cleanup and destroy
 	GLOBALS->changes_count += data->change;
 
-	gtk_widget_destroy (dialog);
+	gtk_window_destroy (GTK_WINDOW(dialog));
 
 	g_free(data);
 	
